@@ -6,8 +6,8 @@
 ;; URL: https://github.com/jamescherti/tomorrow-night-deepblue-theme.el
 ;; Package-Requires: ((emacs "26.1"))
 ;; Keywords: faces themes
-;; Package-Version: 1.2.3
-;; Package-Revision: 1.2.3-0-g85084ded2c4f
+;; Package-Version: 1.2.4
+;; Package-Revision: 1.2.4-0-g0c9ee6ba3b2f
 ;; SPDX-License-Identifier:  GPL-3.0-or-later
 
 ;; This file is NOT part of GNU Emacs.
@@ -1050,31 +1050,31 @@ names to which it refers are bound."
      (gnus-cite-9 ((,class (:foreground ,red))))
      (gnus-emphasis-highlight-words ((,class (:foreground ,yellow :background ,highlight))))
      (gnus-group-mail-1 ((,class (:foreground ,blue :weight normal))))
-     (gnus-group-mail-1-empty ((,class (:inherit gnus-group-mail-1 :foreground ,comment))))
+     (gnus-group-mail-1-empty ((,class (:foreground ,comment :weight normal))))
      (gnus-group-mail-2 ((,class (:foreground ,purple :weight normal))))
-     (gnus-group-mail-2-empty ((,class (:inherit gnus-group-mail-2 :foreground ,comment))))
+     (gnus-group-mail-2-empty ((,class (:foreground ,comment :weight normal))))
      (gnus-group-mail-3 ((,class (:foreground ,aqua :weight normal))))
-     (gnus-group-mail-3-empty ((,class (:inherit gnus-group-mail-3 :foreground ,comment))))
+     (gnus-group-mail-3-empty ((,class (:foreground ,comment :weight normal))))
      (gnus-group-mail-4 ((,class (:foreground ,yellow :weight normal))))
-     (gnus-group-mail-4-empty ((,class (:inherit gnus-group-mail-4 :foreground ,comment))))
+     (gnus-group-mail-4-empty ((,class (:foreground ,comment :weight normal))))
      (gnus-group-mail-5 ((,class (:foreground ,orange :weight normal))))
-     (gnus-group-mail-5-empty ((,class (:inherit gnus-group-mail-5 :foreground ,comment))))
+     (gnus-group-mail-5-empty ((,class (:foreground ,comment :weight normal))))
      (gnus-group-mail-6 ((,class (:foreground ,blue :weight normal))))
-     (gnus-group-mail-6-empty ((,class (:inherit gnus-group-mail-6 :foreground ,comment))))
+     (gnus-group-mail-6-empty ((,class (:foreground ,comment :weight normal))))
      (gnus-group-mail-low ((,class (:foreground ,comment))))
      (gnus-group-mail-low-empty ((,class (:foreground ,comment))))
      (gnus-group-news-1 ((,class (:foreground ,blue :weight normal))))
-     (gnus-group-news-1-empty ((,class (:inherit gnus-group-news-1 :foreground ,comment))))
+     (gnus-group-news-1-empty ((,class (:foreground ,comment :weight normal))))
      (gnus-group-news-2 ((,class (:foreground ,purple :weight normal))))
-     (gnus-group-news-2-empty ((,class (:inherit gnus-group-news-2 :foreground ,comment))))
+     (gnus-group-news-2-empty ((,class (:foreground ,comment :weight normal))))
      (gnus-group-news-3 ((,class (:foreground ,aqua :weight normal))))
-     (gnus-group-news-3-empty ((,class (:inherit gnus-group-news-3 :foreground ,comment))))
+     (gnus-group-news-3-empty ((,class (:foreground ,comment :weight normal))))
      (gnus-group-news-4 ((,class (:foreground ,yellow :weight normal))))
-     (gnus-group-news-4-empty ((,class (:inherit gnus-group-news-4 :foreground ,comment))))
+     (gnus-group-news-4-empty ((,class (:foreground ,comment :weight normal))))
      (gnus-group-news-5 ((,class (:foreground ,orange :weight normal))))
-     (gnus-group-news-5-empty ((,class (:inherit gnus-group-news-5 :foreground ,comment))))
+     (gnus-group-news-5-empty ((,class (:foreground ,comment :weight normal))))
      (gnus-group-news-6 ((,class (:foreground ,blue :weight normal))))
-     (gnus-group-news-6-empty ((,class (:inherit gnus-group-news-6 :foreground ,comment))))
+     (gnus-group-news-6-empty ((,class (:foreground ,comment :weight normal))))
      (gnus-header-content ((,class (:inherit message-header-other))))
      (gnus-header-from ((,class (:inherit message-header-other-face :weight bold :foreground ,orange))))
      (gnus-header-name ((,class (:inherit message-header-name))))
